@@ -3,6 +3,7 @@ use types::{Argc, c_char, c_int, CallbackPtr, Id, Value};
 extern "C" {
     pub fn rb_class_new_instance(argc: Argc, argv: *const Value, klass: Value) -> Value;
     pub fn rb_class_superclass(class: Value) -> Value;
+    pub fn rb_define_attr(klass: Value, name: *const c_char, read: c_int, write: c_int);
     pub fn rb_define_class(name: *const c_char, superclass: Value) -> Value;
     pub fn rb_define_class_under(outer: Value, name: *const c_char, superclass: Value) -> Value;
     pub fn rb_define_method(klass: Value, name: *const c_char, callback: CallbackPtr, argc: Argc);
@@ -11,7 +12,8 @@ extern "C" {
     pub fn rb_ivar_set(object: Value, name: Id, value: Value) -> Value;
     pub fn rb_mod_ancestors(module: Value) -> Value;
     pub fn rb_obj_class(object: Value) -> Value;
-    pub fn rb_respond_to(obj: Value, id: Id) -> c_int;
+    pub fn rb_respond_to(object: Value, id: Id) -> c_int;
+    pub fn rb_singleton_class(object: Value) -> Value;
 
     pub fn rb_define_singleton_method(klass: Value,
                                       name: *const c_char,
